==> EnvNicheR_1.3.tar.gz: EnvNicheR/man/Polar.coordinates.Rd <==
\name{Polar.coordinates}
\docType{data}
\alias{Polar.coordinates}
\title{Polar cooordinates obtained from the function \link{Niche}}
\description{Polar cooordinates.CSV file obtained from the function \link{Niche} using presence data of terrestrial carnivores of the family Felidae and mean of environmental variables in cells of 1 degree x 1 degree around the world.}
\usage{data(Polar.coordinates)}
\format{A matrix with the taxonomy, polar coordinates and mean values of the environemntal variables for each polar coordinate.}
\source{The range maps of the species were obtained from the International Union for Conservation of Nature (IUCN) at the web page http://www.iucn.org/. The data of the mean annual temperature (BIO1), isothermality (BIO3), temperature seasonality (BIO4) and mean annual precipitation (BIO12) were downloaded from the web http://www.worldclim.org/. Both range maps and environmental variables were inputted into ModestR (www.ipez.es/ModestR) and the output file was used in the function Niche() and the file Polar coordinates.CSV obtained was converted to a RData file.}
\references{
Garca-Rosell, E., Guisande, C., Gonzlez-Dacosta, J., Heine, J., Pelayo-Villamil, P., Manjarrs-Hernndez, A., Vaamonde, A. & Granado-Lorencio, C. (2013) ModestR: a software tool for managing and analyzing species distribution map databases. \emph{Ecography}, 36, 1202-1207.

Hijmans, R.J., Cameron, S.E., Parra, J.L., Jones, P.G. and Jarvis, A. (2005) Very high resolution interpolated climate surfaces for global land areas. \emph{International Journal of Climatology}, 25, 1965-1978.

IUCN (2012) The IUCN Red List of Threatened Species. Version 2012.2. <http://www.iucnredlist.org>. Downloaded on 17 October 2012.

Pelayo-Villamil, P., Guisande, C., Gonzlez-Vilas. L., Carvajal-Quintero. J.D., Jimnez-Segura, L.F., Garca-Rosell, E., Heine, J., Gonzlez-Dacosta, J., Manjarrs-Hernndez, A., Vaamonde, A., Granado-Lorencio, C. (2012) ModestR: Una herramienta infromtica para el estudio de los ecosistemas acuticos de Colombia. \emph{Actualidades Biolgicas}, 34, 225-239.
}
\keyword{Polar.coordinates}

==> EnvNicheR_1.4.tar.gz: EnvNicheR/man/Polar.coordinates.Rd <==
\name{Polar.coordinates}
\docType{data}
\alias{Polar.coordinates}
\title{Polar cooordinates obtained from the function \link{Niche}}
\description{Polar cooordinates.CSV file obtained from the function \link{Niche} using presence data of terrestrial carnivores of the family Felidae and mean of environmental variables in cells of 1 degree x 1 degree around the world.}
\usage{data(Polar.coordinates)}
\format{A matrix with the taxonomy, polar coordinates and mean values of the environemntal variables for each polar coordinate.}
\source{The range maps of the species were obtained from the International Union for Conservation of Nature (IUCN) at the web page \url{http://www.iucn.org/}. The data of the mean annual temperature (BIO1), isothermality (BIO3), temperature seasonality (BIO4) and mean annual precipitation (BIO12) were downloaded from the web \url{http://www.worldclim.org/}. Both range maps and environmental variables were inputted into ModestR (\url{http://www.ipez.es/ModestR}) and the output file was used in the function Niche() and the file Polar coordinates.CSV obtained was converted to a RData file.}
\references{
Garca-Rosell, E., Guisande, C., Gonzlez-Dacosta, J., Heine, J., Pelayo-Villamil, P., Manjarrs-Hernndez, A., Vaamonde, A. & Granado-Lorencio, C. (2013) ModestR: a software tool for managing and analyzing species distribution map databases. \emph{Ecography}, 36, 1202-1207.

Hijmans, R.J., Cameron, S.E., Parra, J.L., Jones, P.G. and Jarvis, A. (2005) Very high resolution interpolated climate surfaces for global land areas. \emph{International Journal of Climatology}, 25, 1965-1978.

IUCN (2012) The IUCN Red List of Threatened Species. Version 2012.2. \url{http://www.iucnredlist.org}. Downloaded on 17 October 2012.

Pelayo-Villamil, P., Guisande, C., Gonzlez-Vilas. L., Carvajal-Quintero. J.D., Jimnez-Segura, L.F., Garca-Rosell, E., Heine, J., Gonzlez-Dacosta, J., Manjarrs-Hernndez, A., Vaamonde, A., Granado-Lorencio, C. (2012) ModestR: Una herramienta infromtica para el estudio de los ecosistemas acuticos de Colombia. \emph{Actualidades Biolgicas}, 34, 225-239.
}
\keyword{Polar.coordinates}
